@@ -3,16 +3,16 @@
 
 #include "spacechildrenmodel.h"
 
-#include <Quotient/connection.h>
 #include <Quotient/jobs/basejob.h>
 #include <Quotient/room.h>
 
 #include "neochatconnection.h"
+#include "neochatroom.h"
 
 SpaceChildrenModel::SpaceChildrenModel(QObject *parent)
     : QAbstractItemModel(parent)
+    , m_rootItem(new SpaceTreeItem(nullptr))
 {
-    m_rootItem = new SpaceTreeItem(nullptr);
 }
 
 SpaceChildrenModel::~SpaceChildrenModel()
@@ -32,21 +32,21 @@ void SpaceChildrenModel::setSpace(NeoChatRoom *space)
     }
     // disconnect the new room signal from the old connection in case it is different.
     if (m_space != nullptr) {
-        disconnect(m_space->connection(), &Quotient::Connection::loadedRoomState, this, nullptr);
+        m_space->connection()->disconnect(this);
+        m_space->disconnect(this);
     }
 
     m_space = space;
     Q_EMIT spaceChanged();
 
-    for (auto job : m_currentJobs) {
-        if (job) {
-            job->abandon();
-        }
+    refreshModel();
+
+    if (!m_space) {
+        return;
     }
-    m_currentJobs.clear();
 
     auto connection = m_space->connection();
-    connect(connection, &Quotient::Connection::loadedRoomState, this, [this](Quotient::Room *room) {
+    connect(connection, &NeoChatConnection::loadedRoomState, this, [this](Quotient::Room *room) {
         if (m_pendingChildren.contains(room->name())) {
             m_pendingChildren.removeAll(room->name());
             refreshModel();
@@ -55,8 +55,6 @@ void SpaceChildrenModel::setSpace(NeoChatRoom *space)
     connect(m_space, &Quotient::Room::changed, this, [this]() {
         refreshModel();
     });
-
-    refreshModel();
 }
 
 bool SpaceChildrenModel::loading() const
@@ -66,6 +64,21 @@ bool SpaceChildrenModel::loading() const
 
 void SpaceChildrenModel::refreshModel()
 {
+    for (auto job : m_currentJobs) {
+        if (job) {
+            job->abandon();
+        }
+    }
+    m_currentJobs.clear();
+
+    if (m_space == nullptr) {
+        beginResetModel();
+        delete m_rootItem;
+        m_rootItem = nullptr;
+        endResetModel();
+        return;
+    }
+
     beginResetModel();
     m_replacedRooms.clear();
     delete m_rootItem;
@@ -81,7 +94,11 @@ void SpaceChildrenModel::refreshModel()
     });
 }
 
+#if Quotient_VERSION_MINOR >= 9
+void SpaceChildrenModel::insertChildren(std::vector<Quotient::GetSpaceHierarchyJob::SpaceHierarchyRoomsChunk> children, const QModelIndex &parent)
+#else
 void SpaceChildrenModel::insertChildren(std::vector<Quotient::GetSpaceHierarchyJob::ChildRoomsChunk> children, const QModelIndex &parent)
+#endif
 {
     SpaceTreeItem *parentItem = getItem(parent);
 
@@ -112,6 +129,11 @@ void SpaceChildrenModel::insertChildren(std::vector<Quotient::GetSpaceHierarchyJ
                 if (!successorId.isEmpty()) {
                     m_replacedRooms += successorId;
                 }
+                if (dynamic_cast<NeoChatRoom *>(room)->isSpace()) {
+                    connect(room, &Quotient::Room::changed, this, [this]() {
+                        refreshModel();
+                    });
+                }
             }
             if (children[i].childrenState.size() > 0) {
                 auto job = m_space->connection()->callApi<Quotient::GetSpaceHierarchyJob>(children[i].roomId, Quotient::none, Quotient::none, 1);
@@ -120,19 +142,18 @@ void SpaceChildrenModel::insertChildren(std::vector<Quotient::GetSpaceHierarchyJ
                     insertChildren(job->rooms(), index(insertRow, 0, parent));
                 });
             }
-            parentItem->insertChild(insertRow,
-                                    new SpaceTreeItem(dynamic_cast<NeoChatConnection *>(m_space->connection()),
-                                                      parentItem,
-                                                      children[i].roomId,
-                                                      children[i].name,
-                                                      children[i].canonicalAlias,
-                                                      children[i].topic,
-                                                      children[i].numJoinedMembers,
-                                                      children[i].avatarUrl,
-                                                      children[i].guestCanJoin,
-                                                      children[i].worldReadable,
-                                                      children[i].roomType == QLatin1String("m.space"),
-                                                      std::move(children[i].childrenState)));
+            parentItem->insertChild(std::make_unique<SpaceTreeItem>(dynamic_cast<NeoChatConnection *>(m_space->connection()),
+                                                                    parentItem,
+                                                                    children[i].roomId,
+                                                                    children[i].name,
+                                                                    children[i].canonicalAlias,
+                                                                    children[i].topic,
+                                                                    children[i].numJoinedMembers,
+                                                                    children[i].avatarUrl,
+                                                                    children[i].guestCanJoin,
+                                                                    children[i].worldReadable,
+                                                                    children[i].roomType == QLatin1String("m.space"),
+                                                                    std::move(children[i].childrenState)));
         }
     }
     endInsertRows();
@@ -244,6 +265,20 @@ QVariant SpaceChildrenModel::data(const QModelIndex &index, int role) const
         }
         return QVariant::fromValue(nullptr);
     }
+    if (role == OrderRole) {
+        if (child->parentItem() == nullptr) {
+            return QString();
+        }
+        const auto childState = child->parentItem()->childStateContent(child);
+        return childState[QLatin1String("order")].toString();
+    }
+    if (role == ChildTimestampRole) {
+        if (child->parentItem() == nullptr) {
+            return QString();
+        }
+        const auto childState = child->parentItem()->childState(child);
+        return childState[QLatin1String("origin_server_ts")].toString();
+    }
 
     return {};
 }
@@ -325,6 +360,8 @@ QHash<int, QByteArray> SpaceChildrenModel::roleNames() const
     roles[IsDeclaredParentRole] = "isDeclaredParent";
     roles[CanRemove] = "canRemove";
     roles[ParentRoomRole] = "parentRoom";
+    roles[OrderRole] = "order";
+    roles[ChildTimestampRole] = "childTimestamp";
 
     return roles;
 }
