@@ -126,6 +126,20 @@ class NeoChatRoom : public Quotient::Room
      */
     Q_PROPERTY(bool isSpace READ isSpace CONSTANT)
 
+    /**
+     * @brief The number of notifications in this room's children.
+     *
+     * Will always return 0 if this is not a space.
+     */
+    Q_PROPERTY(qsizetype childrenNotificationCount READ childrenNotificationCount NOTIFY childrenNotificationCountChanged)
+
+    /**
+     * @brief Whether this room's children have any highlight notifications.
+     *
+     * Will always return false if this is not a space.
+     */
+    Q_PROPERTY(bool childrenHaveHighlightNotifications READ childrenHaveHighlightNotifications NOTIFY childrenHaveHighlightNotificationsChanged)
+
     /**
      * @brief Whether the local user has an invite to the room.
      *
@@ -398,6 +412,16 @@ public:
      */
     [[nodiscard]] bool lastEventIsSpoiler() const;
 
+    /**
+     * @brief Return the notification count for the room accounting for tags and notification state.
+     *
+     * The following rules are observed:
+     *  - Rooms tagged as low priority or mentions and keywords notification state
+     *    only return the number of highlights.
+     *  - Muted rooms always return 0.
+     */
+    int contextAwareNotificationCount() const;
+
     [[nodiscard]] bool hasFileUploading() const;
     void setHasFileUploading(bool value);
 
@@ -524,7 +548,11 @@ public:
      */
     Q_INVOKABLE void removeParent(const QString &parentId);
 
-    [[nodiscard]] bool isSpace();
+    [[nodiscard]] bool isSpace() const;
+
+    qsizetype childrenNotificationCount();
+
+    bool childrenHaveHighlightNotifications() const;
 
     /**
      * @brief Add the given room as a child.
@@ -532,7 +560,7 @@ public:
      * Will fail if the user doesn't have the required privileges or this room is
      * not a space.
      */
-    Q_INVOKABLE void addChild(const QString &childId, bool setChildParent = false, bool canonical = false, bool suggested = false);
+    Q_INVOKABLE void addChild(const QString &childId, bool setChildParent = false, bool canonical = false, bool suggested = false, const QString &order = {});
 
     /**
      * @brief Remove the given room as a child.
@@ -555,6 +583,8 @@ public:
      */
     Q_INVOKABLE void toggleChildSuggested(const QString &childId);
 
+    void setChildOrder(const QString &childId, const QString &order = {});
+
     bool isInvite() const;
 
     bool readOnly() const;
@@ -629,6 +659,8 @@ public:
      * */
     Q_INVOKABLE void setCanonicalAlias(const QString &newAlias);
 
+    Q_INVOKABLE void setRoomState(const QString &type, const QString &stateKey, const QByteArray &content);
+
     PushNotificationState::State pushNotificationState() const;
     void setPushNotificationState(PushNotificationState::State state);
 
@@ -815,6 +847,8 @@ Q_SIGNALS:
     void parentIdsChanged();
     void canonicalParentChanged();
     void lastActiveTimeChanged();
+    void childrenNotificationCountChanged();
+    void childrenHaveHighlightNotificationsChanged();
     void isInviteChanged();
     void readOnlyChanged();
     void displayNameChanged();
